# apstools

Various Python tools for use with the Bluesky framework at the APS

[![Python version](https://img.shields.io/pypi/pyversions/apstools.svg)](https://pypi.python.org/pypi/apstools)
![Unit Tests](https://github.com/BCDA-APS/apstools/workflows/Unit%20Tests/badge.svg)
[![Documentation Status](https://readthedocs.org/projects/apstools/badge/?version=latest)](http://apstools.readthedocs.io/en/latest/?badge=latest)
[![Coverage Status](https://coveralls.io/repos/github/BCDA-APS/apstools/badge.svg?branch=main)](https://coveralls.io/github/BCDA-APS/apstools?branch=main)

[![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/BCDA-APS/apstools.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/BCDA-APS/apstools/context:python)
[![Total alerts](https://img.shields.io/lgtm/alerts/g/BCDA-APS/apstools.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/BCDA-APS/apstools/alerts/)

[![release](https://img.shields.io/github/release/BCDA-APS/apstools.svg)](https://github.com/BCDA-APS/apstools/releases)
[![PyPi](https://img.shields.io/pypi/v/apstools.svg)](https://pypi.python.org/pypi/apstools)
[![conda](https://anaconda.org/aps-anl-tag/apstools/badges/version.svg)](https://anaconda.org/aps-anl-tag/apstools)

## Package Information

item              | description
------------------|--------------------------------
**author**        | Pete R. Jemian
**email**         | jemian@anl.gov
**copyright**     | 2017-2022, UChicago Argonne, LLC
[**license**](LICENSE.txt) | ANL OPEN SOURCE LICENSE
[**documentation**](https://bcda-aps.github.io/apstools/) | latest tagged release
**source**        | https://github.com/BCDA-APS/apstools


## See also
* https://BCDA-APS.github.io/apsbss
* https://blueskyproject.io/
* https://github.com/bluesky/bluesky
* https://github.com/bluesky/ophyd
* https://github.com/bluesky/databroker
* https://github.com/bluesky/hklpy
